@@ -161,7 +161,7 @@ def read_geom(geom_path):
             size : list of length 3
                 Volume element size. By default set to unit size: [1, 1, 1].
             origin : list of length 3
-                Volume element origin. By default: [0, 0, 0].                
+                Volume element origin. By default: [0, 0, 0].
             material_homog_idx : 1D ndarray of str
                 Determines the homogenization scheme for each material.
             orientations : dict
@@ -221,10 +221,15 @@ def read_geom(geom_path):
         texture_match = re.search(pat, lines)
         if texture_match:
             texture_str = texture_match.group()
-            orientations = parse_texture_gauss(texture_str)
+            texture_gauss = parse_texture_gauss(texture_str)
+            orientations = {
+                'type': 'euler',
+                'euler_angles': texture_gauss['euler_angles'],
+                'euler_angle_labels': texture_gauss['euler_angle_labels'],
+            }
 
         # Check indices in `constituent_orientation_idx` are valid, given `orientations`:
-        if (
+        if ms_match and (
             np.min(constituent_orientation_idx) < 0 or
             np.max(constituent_orientation_idx) > len(orientations['euler_angles'])
         ):
@@ -232,7 +237,8 @@ def read_geom(geom_path):
             raise ValueError(msg)
 
         # Parse header information:
-        size_pat = r'size\s+x\s+(\d+\.\d+)\s+y\s+(\d+\.\d+)\s+z\s+(\d+\.\d+)'
+        size_pat = (r'size\s+x\s+(\d+(?:\.\d+)*)'
+                    r'\s+y\s+(\d+(?:\.\d+)*)\s+z\s+(\d+(?:\.\d+)*)')
         size_match = re.search(size_pat, lines)
         size = None
         if size_match:
@@ -455,7 +461,7 @@ def read_material(path):
     Parameters
     ----------
     path : str or Path
-        Path to the DAMASK material.yaml file.    
+        Path to the DAMASK material.yaml file.
 
     Returns
     -------
@@ -465,7 +471,7 @@ def read_material(path):
                 The "phase" dict contained within the material file.
             homog_schemes : dict
                 The "homogenization" dict contained within the material file.
-            volume_element : dict            
+            volume_element : dict
                 Dict representing the volume element. The distribution of materials
                 across the elements (i.e. keys `element_material_idx` and `grid_size`)
                 are not included, since this information is not contained in the
@@ -493,7 +499,7 @@ def read_material(path):
                                 Value is "quat".
                             quaternions : ndarray of shape (R, 4) of float, optional
                                 Array of R row four-vectors of unit quaternions. Specify
-                                either `quaternions` or `euler_angles`.        
+                                either `quaternions` or `euler_angles`.
 
     """
 
@@ -537,14 +543,14 @@ def read_material(path):
     return material_data
 
 
-def geom_to_volume_element(geom_path, phase_labels, homog_label):
+def geom_to_volume_element(geom_path, phase_labels, homog_label, orientations=None):
     """Read a DAMASK geom file and parse to a volume element.
 
     Parameters
     ----------
     geom_path : str or Path
         Path to the DAMASK geometry file. The geom file must include texture and
-        microstructure parts in its header.
+        microstructure parts in its header if `orientations` is None.
     phase_labels : list or ndarray of str, optional
         List of phase labels to associate with the constituents. The first list element is
         the phase label that will be associated with all of the geometrical elements
@@ -555,7 +561,19 @@ def geom_to_volume_element(geom_path, phase_labels, homog_label):
         the phases assigned to those additional material indices would be specified as
         additional list elements in `phase_labels`.
     homog_label : str, optional
-        The homogenization scheme label to use for all materials in the volume element. 
+        The homogenization scheme label to use for all materials in the volume element.
+    orientations : dict, optional
+        If specified, use these orientations instead of those that might be specified in
+        the geometry file. Dict containing the following keys:
+            type : str
+                One of "euler", "quat".
+            quaternions : (list or ndarray of shape (R, 4)) of float, optional
+                Array of R row four-vectors of unit quaternions. Specify either
+                `quaternions` or `euler_angles`.
+            euler_angles : (list or ndarray of shape (R, 3)) of float, optional            
+                Array of R row three-vectors of Euler angles. Specify either `quaternions`
+                or `euler_angles`. Specified as proper Euler angles in the Bunge
+                convention (rotations are about Z, new-X, new-new-Z).        
 
     Returns
     -------
@@ -565,12 +583,10 @@ def geom_to_volume_element(geom_path, phase_labels, homog_label):
 
     geom_dat = read_geom(geom_path)
     volume_element = {
-        'orientations': {
-            'type': 'euler',
-            'euler_angles': geom_dat['orientations']['euler_angles'],
-        },
+        'orientations': orientations or geom_dat['orientations'],
         'element_material_idx': geom_dat['element_material_idx'],
         'grid_size': geom_dat['grid_size'],
+        'size': geom_dat['size'],
         'phase_labels': phase_labels,
         'homog_label': homog_label,
     }
